@@ -1,7 +1,9 @@
+from django.apps import apps
 from django.conf import settings
 import pytest
 from rgd import models
 from rgd.permissions import filter_read_perm
+from rgd_testing_utils.helpers import check_model_permissions
 
 
 @pytest.mark.django_db(transaction=True)
@@ -20,3 +22,8 @@ def test_unassigned_permissions_complex(user_factory, user, spatial_asset_a, spa
     assert len(admin_q) == len(basic_q)
     assert set(admin_q) == set(basic_q)
     settings.RGD_GLOBAL_READ_ACCESS = prior
+
+
+def test_check_permissions_path_rgd():
+    for model in apps.get_app_config('rgd').get_models():
+        check_model_permissions(model)
